@@ -12,11 +12,11 @@ commands = {
 def allowed(command):
 
     return command in commands
-def execute(command, options):
+def execute(command, options, print_results=True):
 
     if not command in commands:
         raise ValueError("Unknown command %s" % command)
 
     module = importlib.import_module('.%s' % commands[command], __name__)
 
-    module.execute(options)
+    return module.execute(options, print_results=print_results)
